wurfl2python.DeviceSerializer

Module wurfl2python :: Class DeviceSerializer |
[hide private]
[frames] | no frames]

# Class DeviceSerializer

source code

                              object --+
                                       |
    pywurfl.wurflprocessor.DeviceHandler --+
                                           |
                                          DeviceSerializer

Instance Methods | [hide private]
encoded_str(self) | source code
Inherited from `pywurfl.wurflprocessor.DeviceHandler`: `__init__` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| idstr = ``u'``devices.devids[ur'''%s'''] =` `'``
| new_caps = ``u'``devices.devids[ur'''%s'''] = devclass(%s, ur'''%s``...``
| no_caps = ``u'``devices.devids[ur'''%s'''] = devclass(%s, ur'''%s'``...``
| capability_types = ``{``}``

Properties | [hide private]
Inherited from `object`: `__class__`

Class Variable Details | [hide private]

  ### new_caps Value:
      u'''devices.devids[ur'''%s'''] = devclass(%s, ur'''%s''', ur'''%s''',
      %s, {%s})
      '''

  ### no_caps Value:
      u'''devices.devids[ur'''%s'''] = devclass(%s, ur'''%s''', ur'''%s''',
      %s, None)
      '''